@@ -120,7 +120,29 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                engine: aws_cdk.aws_rds.IClusterEngine,
+                snapshot_identifier: builtins.str,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                backup_retention: typing.Optional[aws_cdk.Duration] = None,
+                cluster_identifier: typing.Optional[builtins.str] = None,
+                credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
+                default_database_name: typing.Optional[builtins.str] = None,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                enable_data_api: typing.Optional[builtins.bool] = None,
+                parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ServerlessClusterFromSnapshotProps(
@@ -167,7 +189,17 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.add_rotation_multi_user)
+            def stub(
+                id: builtins.str,
+                *,
+                secret: aws_cdk.aws_secretsmanager.ISecret,
+                automatically_after: typing.Optional[aws_cdk.Duration] = None,
+                endpoint: typing.Optional[aws_cdk.aws_ec2.IInterfaceVpcEndpoint] = None,
+                exclude_characters: typing.Optional[builtins.str] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         options = aws_cdk.aws_rds.RotationMultiUserOptions(
             secret=secret,
@@ -228,7 +260,9 @@ class ServerlessClusterFromSnapshot(
         :stability: deprecated
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshot.grant_data_api_access)
+            def stub(grantee: aws_cdk.aws_iam.IGrantable) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(aws_cdk.aws_iam.Grant, jsii.invoke(self, "grantDataApiAccess", [grantee]))
 
@@ -297,7 +331,9 @@ class ServerlessClusterFromSnapshot(
     @_enable_data_api.setter
     def _enable_data_api(self, value: typing.Optional[builtins.bool]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ServerlessClusterFromSnapshot, "_enable_data_api").fset)
+            def stub(value: typing.Optional[builtins.bool]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableDataApi", value)
 
@@ -371,7 +407,27 @@ class ServerlessClusterFromSnapshotProps:
         if isinstance(vpc_subnets, dict):
             vpc_subnets = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnets)
         if __debug__:
-            type_hints = typing.get_type_hints(ServerlessClusterFromSnapshotProps.__init__)
+            def stub(
+                *,
+                engine: aws_cdk.aws_rds.IClusterEngine,
+                snapshot_identifier: builtins.str,
+                vpc: aws_cdk.aws_ec2.IVpc,
+                backup_retention: typing.Optional[aws_cdk.Duration] = None,
+                cluster_identifier: typing.Optional[builtins.str] = None,
+                credentials: typing.Optional[aws_cdk.aws_rds.Credentials] = None,
+                default_database_name: typing.Optional[builtins.str] = None,
+                deletion_protection: typing.Optional[builtins.bool] = None,
+                enable_data_api: typing.Optional[builtins.bool] = None,
+                parameter_group: typing.Optional[aws_cdk.aws_rds.IParameterGroup] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                scaling: typing.Optional[typing.Union[aws_cdk.aws_rds.ServerlessScalingOptions, typing.Dict[str, typing.Any]]] = None,
+                security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+                storage_encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                subnet_group: typing.Optional[aws_cdk.aws_rds.ISubnetGroup] = None,
+                vpc_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument engine", value=engine, expected_type=type_hints["engine"])
             check_type(argname="argument snapshot_identifier", value=snapshot_identifier, expected_type=type_hints["snapshot_identifier"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
